@@ -32,27 +32,6 @@ def create_devops_terraform_build_config(stage,
                 'additional_tfvar_files': additional_tfvar_files})
     return ret
 
-
-class WorkaroundTerraform(Terraform):
-    def __init__(self, working_dir=None,
-                 targets=None,
-                 state=None,
-                 variables=None,
-                 parallelism=None,
-                 var_file=None,
-                 terraform_bin_path=None,
-                 is_env_vars_included=True,
-                 ):
-        super().__init__(working_dir, targets, state, variables, parallelism,
-                         var_file,  terraform_bin_path, is_env_vars_included)
-        self.latest_cmd = ''
-
-    def generate_cmd_string(self, cmd, *args, **kwargs):
-        result = super().generate_cmd_string(cmd, *args, **kwargs)
-        self.latest_cmd = ' '.join(result)
-        return result
-
-
 class DevopsTerraformBuild(DevopsBuild):
 
     def __init__(self, project, config):
@@ -116,7 +95,7 @@ class DevopsTerraformBuild(DevopsBuild):
         self.rescue_local_state()
         
     def init_client(self):
-        tf = WorkaroundTerraform(working_dir=self.build_path())
+        tf = Terraform(working_dir=self.build_path())
         tf.init()
         self.print_terraform_command(tf)
         if self.use_workspace:
@@ -172,6 +151,17 @@ class DevopsTerraformBuild(DevopsBuild):
         if (return_code > 0):
             raise Exception(return_code, "terraform error:", stderr)
 
+    def refresh(self, auto_approve=True):
+        tf = self.init_client()
+        return_code, stdout, stderr = tf.refresh(
+                var=self.project_vars(),
+                var_file=self.additional_tfvar_files)
+        self.write_output(tf)
+        self.post_build()
+        self.print_terraform_command(tf)
+        if (return_code > 0):
+            raise Exception(return_code, "terraform error:", stderr)
+
     def destroy(self, auto_approve=False):
         tf = self.init_client()
         if auto_approve:
